-- ------------------------------------------------------------------- 
-- Explain Lab 04 - Union All View Setup #1
-- ------------------------------------------------------------------- 
-- This script creates the buffer pools, table spaces and tables 
-- needed to show a union all view.  Then it creates the union all
-- View itself.  Tables are named Q1_2004 through Q4_2004.  
-- View is YEAR_2004.
-- ------------------------------------------------------------------- 
-- Thanks to George Baklarz for the source of this example
-- ------------------------------------------------------------------- 

--------------------------------
-- CREATE BUFFERPOOLS 	     --
--------------------------------

ECHO -;
ECHO -------------------------;
ECHO Creating Buffer Pools...;
ECHO -------------------------;


CREATE BUFFERPOOL BP4_DATA
IMMEDIATE  
SIZE 2000 
PAGESIZE 4 K  
EXTENDED STORAGE ;

CREATE BUFFERPOOL BP4_INDEX
IMMEDIATE  
SIZE 2000 
PAGESIZE 4 K  
EXTENDED STORAGE ;

--------------------------------
-- CREATE DMS TABLESPACES     --
--------------------------------
ECHO -;
ECHO -------------------------;
ECHO Creating Tablespaces...;
ECHO -------------------------;

DROP TABLE Q1_2004;
DROP TABLE Q2_2004;
DROP TABLE Q3_2004;
DROP TABLE Q4_2004;

DROP TABLESPACE Q1_2004_DATA;
DROP TABLESPACE Q2_2004_DATA;
DROP TABLESPACE Q3_2004_DATA;
DROP TABLESPACE Q4_2004_DATA;
DROP TABLESPACE Q1_2004_INDEX;
DROP TABLESPACE Q2_2004_INDEX;
DROP TABLESPACE Q3_2004_INDEX;
DROP TABLESPACE Q4_2004_INDEX;

CREATE  REGULAR  TABLESPACE Q1_2004_DATA 
PAGESIZE 4 K  
MANAGED BY DATABASE  
USING ( FILE 'C:\DB2\Q1_2004_DATA_CONTAINER1.DBF' 640 ) 
EXTENTSIZE 16 
OVERHEAD 10.5 
PREFETCHSIZE 16 
TRANSFERRATE 0.14 
BUFFERPOOL  BP4_DATA 
DROPPED TABLE RECOVERY ON;

CREATE  REGULAR  TABLESPACE Q1_2004_INDEX 
PAGESIZE 4 K  
MANAGED BY DATABASE  
USING ( FILE 'C:\DB2\Q1_2004_INDEX_CONTAINER1.DBF' 640 ) 
EXTENTSIZE 16 
OVERHEAD 10.5 
PREFETCHSIZE 16 
TRANSFERRATE 0.14 
BUFFERPOOL  BP4_INDEX
DROPPED TABLE RECOVERY ON;

CREATE  REGULAR  TABLESPACE Q2_2004_DATA 
PAGESIZE 4 K  
MANAGED BY DATABASE  
USING ( FILE 'C:\DB2\Q2_2004_DATA_CONTAINER1.DBF' 640 ) 
EXTENTSIZE 16 
OVERHEAD 10.5 
PREFETCHSIZE 16 
TRANSFERRATE 0.14 
BUFFERPOOL  BP4_DATA 
DROPPED TABLE RECOVERY ON;

CREATE  REGULAR  TABLESPACE Q2_2004_INDEX 
PAGESIZE 4 K  
MANAGED BY DATABASE  
USING ( FILE 'C:\DB2\Q2_2004_INDEX_CONTAINER1.DBF' 640 ) 
EXTENTSIZE 16 
OVERHEAD 10.5 
PREFETCHSIZE 16 
TRANSFERRATE 0.14 
BUFFERPOOL  BP4_INDEX
DROPPED TABLE RECOVERY ON;

CREATE  REGULAR  TABLESPACE Q3_2004_DATA 
PAGESIZE 4 K  
MANAGED BY DATABASE  
USING ( FILE 'C:\DB2\Q3_2004_DATA_CONTAINER1.DBF' 640 ) 
EXTENTSIZE 16 
OVERHEAD 10.5 
PREFETCHSIZE 16 
TRANSFERRATE 0.14 
BUFFERPOOL  BP4_DATA 
DROPPED TABLE RECOVERY ON;

CREATE  REGULAR  TABLESPACE Q3_2004_INDEX 
PAGESIZE 4 K  
MANAGED BY DATABASE  
USING ( FILE 'C:\DB2\Q3_2004_INDEX_CONTAINER1.DBF' 640 ) 
EXTENTSIZE 16 
OVERHEAD 10.5 
PREFETCHSIZE 16 
TRANSFERRATE 0.14 
BUFFERPOOL  BP4_INDEX
DROPPED TABLE RECOVERY ON;

CREATE  REGULAR  TABLESPACE Q4_2004_DATA 
PAGESIZE 4 K  
MANAGED BY DATABASE  
USING ( FILE 'C:\DB2\Q4_2004_DATA_CONTAINER1.DBF' 640 ) 
EXTENTSIZE 16 
OVERHEAD 10.5 
PREFETCHSIZE 16 
TRANSFERRATE 0.14 
BUFFERPOOL  BP4_DATA 
DROPPED TABLE RECOVERY ON;

CREATE  REGULAR  TABLESPACE Q4_2004_INDEX 
PAGESIZE 4 K  
MANAGED BY DATABASE  
USING ( FILE 'C:\DB2\Q4_2004_INDEX_CONTAINER1.DBF' 640 ) 
EXTENTSIZE 16 
OVERHEAD 10.5 
PREFETCHSIZE 16 
TRANSFERRATE 0.14 
BUFFERPOOL  BP4_INDEX
DROPPED TABLE RECOVERY ON;

--------------------------------
-- CREATE 4 QUARTERLY TABLES  --
--------------------------------

ECHO -;
ECHO -------------------------;
ECHO Creating Tables...;
ECHO -------------------------;

create table Q1_2004
  (
  tx_number  int not null,
  tx_item    char(10) not null,
  tx_quantity int not null,
  tx_date    date not null,
     check (tx_date between '2004-01-01' and '2004-03-31')
  )
  in Q1_2004_DATA index in Q1_2004_INDEX;

create table Q2_2004
  (
  tx_number  int not null,
  tx_item    char(10) not null,
  tx_quantity int not null,
  tx_date    date not null,
     check (tx_date between '2004-04-01' and '2004-06-30')
  )
in Q2_2004_DATA index in Q2_2004_INDEX;


create table Q3_2004
  (
  tx_number  int not null,
  tx_item    char(10) not null,
  tx_quantity int not null,
  tx_date    date not null,
     check (tx_date between '2004-07-01' and '2004-09-30')
  )
in Q3_2004_DATA index in Q3_2004_INDEX;


create table Q4_2004
  (
  tx_number  int not null,
  tx_item    char(10) not null,
  tx_quantity int not null,
  tx_date    date not null,
     check (tx_date between '2004-10-01' and '2004-12-31')
  )
  in Q4_2004_DATA index in Q4_2004_INDEX;


--------------------------------
-- CREATE UNION ALL VIEW      --
--------------------------------

ECHO -;
ECHO -------------------------;
ECHO Creating Union All View...;
ECHO -------------------------;

drop   view Year_2004;
create view Year_2004 as
  (
  select * from Q1_2004
  union all
  select * from Q2_2004
  union all 
  select * from Q3_2004
  union all
  select * from Q4_2004
  ) 
WITH ROW MOVEMENT;

COMMIT WORK;
