-- ------------------------------------------------------------------- 
-- MDC Lab 06 - Create data generation and checking stored procedures
-- ------------------------------------------------------------------- 
-- This script creates 5 stored procedures.  They are:
-- CARS_INSERT_ALL, CARS_INSERT_CHK, CARS_FETCH_CHK,
-- CARS_UPDATE_CHK and CARS_DELETE_CHK.  
--
-- The first inserts identical record sets into both tables.  This
-- first stored procedure is run to populate both tables.
--
-- The other 4 stored procedures run checks against the various DML 
-- actions against those tables.  These will be run by you manually
-- during the lab.

ECHO -@
ECHO -------------------------@
ECHO Creating CARS Example Stored procedures..@
ECHO -------------------------@

ECHO -@
ECHO -------------------------@
ECHO Creating CARS_INSERT_ALL Stored procedure..@
ECHO -------------------------@

DROP PROCEDURE CARS_INSERT_ALL@

CREATE PROCEDURE CARS_INSERT_ALL (
	IN i_TOTAL_RECORDS INTEGER, 
	IN i_CAR_COUNT 	INTEGER, 
	IN i_COLOR_COUNT 	INTEGER,
	IN i_YEAR_COUNT	INTEGER)

SPECIFIC CARS_INSERT_ALL
RESULT SETS 0
MODIFIES SQL DATA
LANGUAGE SQL

BEGIN
	DECLARE v_TOTAL_RECORDS	INTEGER DEFAULT 0;
	DECLARE v_CAR_COUNT	INTEGER DEFAULT 0;
	DECLARE v_COLOR_COUNT	INTEGER DEFAULT 0;
	DECLARE v_YEAR_COUNT	INTEGER DEFAULT 0;

	DECLARE v_LOOP1		INTEGER DEFAULT 1;
	DECLARE v_LOOP2		INTEGER DEFAULT 1;

	DECLARE v_CAR_RAND		INTEGER DEFAULT 0;
	DECLARE v_COLOR_RAND	INTEGER DEFAULT 0;
	DECLARE v_YEAR_RAND	INTEGER DEFAULT 0;
	DECLARE v_AVAIL_RAND	SMALLINT DEFAULT 0;

	DECLARE v_CAR_TEXT		VARCHAR(20) DEFAULT 'X';
	DECLARE v_COLOR_TEXT	VARCHAR(10) DEFAULT 'X';
	DECLARE v_YEAR_TEXT	CHAR(4)     DEFAULT 'X';

--	MAXIMUM RECORDS YOU CAN INSERT IS 250,000
	IF i_TOTAL_RECORDS <= 250000 THEN
   	    SET v_TOTAL_RECORDS 	= i_TOTAL_RECORDS;
	ELSE
	    SET v_TOTAL_RECORDS	= 1;
	END IF;

--	MAXIMUM DIFFERENT CARS IS 12
	IF  i_CAR_COUNT <= 12 THEN
	    SET v_CAR_COUNT	= i_CAR_COUNT;
	ELSE
	    SET v_CAR_COUNT	= 13;
	END IF;

--	MAXIMUM	DIFFERENT COLORS IS 12
	IF  i_COLOR_COUNT <= 12 THEN
	    SET v_COLOR_COUNT	= i_COLOR_COUNT;
	ELSE
	    SET v_COLOR_COUNT 	= 13;
	END IF;

--	MAXIMUM	DIFFERENT YEARS IS 5
	IF  i_YEAR_COUNT <= 5 THEN
	    SET v_YEAR_COUNT	= i_YEAR_COUNT;
	ELSE
	    SET v_YEAR_COUNT 	= 5;
	END IF;

WHILE 	v_LOOP1 <= v_TOTAL_RECORDS DO  

	-- GENERATE FAKE CAR DATA
	SET v_CAR_RAND = INT(rand() * v_CAR_COUNT);

	CASE v_CAR_RAND
	WHEN 0  THEN SET v_CAR_TEXT = 'VW BUG';
	WHEN 1  THEN SET v_CAR_TEXT = 'CORVETTE STING RAY';
	WHEN 2  THEN SET v_CAR_TEXT = 'FERRARI F40';
	WHEN 3  THEN SET v_CAR_TEXT = 'VIPER GTS';
	WHEN 4  THEN SET v_CAR_TEXT = 'LAMBORGHINI COUNTACH';
	WHEN 5  THEN SET v_CAR_TEXT = 'GT-40';
	WHEN 6  THEN SET v_CAR_TEXT = 'MIATA';
	WHEN 7  THEN SET v_CAR_TEXT = 'MINI COOPER';
	WHEN 8  THEN SET v_CAR_TEXT = 'PORCHE 911';
	WHEN 9  THEN SET v_CAR_TEXT = 'SHELBY COBRA';
	WHEN 10 THEN SET v_CAR_TEXT = 'JAGUAR E-TYPE';
	WHEN 11 THEN SET v_CAR_TEXT = 'MCLAREN F1';
	ELSE 	       SET v_CAR_TEXT = 'AMC PACER';
	END CASE;

	-- GENERATE FAKE COLOR DATA 
	SET v_COLOR_RAND = INT(rand() * v_COLOR_COUNT);

	CASE v_COLOR_RAND
	WHEN 0  THEN SET v_COLOR_TEXT = 'BROWN';
	WHEN 1  THEN SET v_COLOR_TEXT = 'RED';
	WHEN 2  THEN SET v_COLOR_TEXT = 'BLUE';
	WHEN 3  THEN SET v_COLOR_TEXT = 'GREEN';
	WHEN 4  THEN SET v_COLOR_TEXT = 'YELLOW';
	WHEN 5  THEN SET v_COLOR_TEXT = 'PURPLE';
	WHEN 6  THEN SET v_COLOR_TEXT = 'BLACK';
	WHEN 7  THEN SET v_COLOR_TEXT = 'SILVER';
	WHEN 8  THEN SET v_COLOR_TEXT = 'GREY';
	WHEN 9  THEN SET v_COLOR_TEXT = 'ORANGE';
	WHEN 10 THEN SET v_COLOR_TEXT = 'PINK';
	WHEN 11 THEN SET v_COLOR_TEXT = 'WHITE';
	ELSE 	       SET v_COLOR_TEXT = 'CLEAR';
	END CASE;

	-- GENERATE FAKE YEAR DATA
	SET v_YEAR_RAND = INT(rand() * v_YEAR_COUNT);
	SET v_YEAR_TEXT = CHAR(v_YEAR_RAND + 1999);

	-- GENERATE FAKE AVAILABLE AMOUNT DATA
	SET v_AVAIL_RAND = SMALLINT(rand() * 5);

	-- INSERT IT INTO BOTH TABLES
	INSERT INTO CARS VALUES (v_CAR_TEXT, v_COLOR_TEXT, v_YEAR_TEXT, v_AVAIL_RAND) WITH UR;
	INSERT INTO CARS_MDC VALUES (v_CAR_TEXT, v_COLOR_TEXT, v_YEAR_TEXT, v_AVAIL_RAND) WITH UR;
    

	-- COMMIT EVERY 10,000 INSERTS
	IF 	v_LOOP2 <= 10000 THEN
		SET v_LOOP2 = v_LOOP2 + 1;
	ELSE
		COMMIT;
		SET v_LOOP2 = 0;
	END IF;

    SET v_LOOP1 = v_LOOP1 + 1;

END WHILE;

END@



-- ------------------------------------------------------------------- 
-- ------------------------------------------------------------------- 
ECHO -@
ECHO -------------------------@
ECHO Creating CARS_FETCH_CHK Stored procedure..@
ECHO -------------------------@

DROP   PROCEDURE CARS_FETCH_CHK@

CREATE PROCEDURE CARS_FETCH_CHK (
		     IN i_COLOR CHAR(10) ) 
	
SPECIFIC CARS_FETCH_CHK
RESULT SETS 0
MODIFIES SQL DATA
LANGUAGE SQL

BEGIN	DECLARE v_START TIMESTAMP;
	DECLARE v_STOP  TIMESTAMP;
	DECLARE v_TOTAL BIGINT;

	DECLARE v_START_MDC TIMESTAMP;
	DECLARE v_STOP_MDC  TIMESTAMP;
	DECLARE v_TOTAL_MDC BIGINT;
	DECLARE v_COLOR	 CHAR(10);
	DECLARE v_HOLD	 CHAR(20);
	DECLARE v_ATEND	 INTEGER DEFAULT 0;

	DECLARE v_CARS_CUR CURSOR FOR SELECT CARNAME FROM CARS WHERE COLOR = v_COLOR;
	DECLARE v_CARS_CUR_MDC CURSOR FOR SELECT CARNAME FROM CARS_MDC WHERE COLOR = v_COLOR;
	DECLARE CONTINUE HANDLER FOR NOT FOUND SET v_ATEND = 1;

	SET v_COLOR = UPPER(i_COLOR);

--	------------------------
--	SELECTING FROM CARS_MDC
--	------------------------
	SET v_ATEND = 0;
	OPEN v_CARS_CUR_MDC;

	SET v_START_MDC = CURRENT TIMESTAMP;
	loop2:
	LOOP
		FETCH v_CARS_CUR_MDC into v_HOLD;
		IF v_ATEND <> 0 THEN LEAVE loop2;
		END IF;
	END LOOP loop2;

	SET v_STOP_MDC  = CURRENT TIMESTAMP;
	SET v_TOTAL_MDC = TIMESTAMPDIFF(1, CHAR(v_STOP_MDC - v_START_MDC));	
	
	INSERT INTO CARS_TIMING_CHECK VALUES ('FETCH','CARS_MDC',v_COLOR,v_START_MDC, v_STOP_MDC, v_TOTAL_MDC);

--	--------------------
--	SELECTING FROM CARS
--	--------------------
	SET v_ATEND = 0;
	OPEN v_CARS_CUR;

	SET v_START = CURRENT TIMESTAMP;
	loop1:
	LOOP
		FETCH v_CARS_CUR into v_HOLD;
		IF v_ATEND <> 0 THEN LEAVE loop1;
		END IF;
	END LOOP loop1;
	
	SET v_STOP  = CURRENT TIMESTAMP;
	SET v_TOTAL = TIMESTAMPDIFF(1, CHAR(v_STOP - v_START));	

	INSERT INTO CARS_TIMING_CHECK VALUES ('FETCH','CARS',v_COLOR,v_START, v_STOP, v_TOTAL);
	
	COMMIT;

END@


-- ------------------------------------------------------------------- 
-- ------------------------------------------------------------------- 
ECHO -@
ECHO -------------------------@
ECHO Creating CARS_DELETE_CHK Stored procedure..@
ECHO -------------------------@

DROP PROCEDURE CARS_DELETE_CHK@

CREATE PROCEDURE CARS_DELETE_CHK (
		     IN i_COLOR CHAR(10) ) 
	
SPECIFIC CARS_DELETE_CHK
RESULT SETS 0
MODIFIES SQL DATA
LANGUAGE SQL

BEGIN	DECLARE v_START TIMESTAMP;
	DECLARE v_STOP  TIMESTAMP;
	DECLARE v_TOTAL BIGINT;

	DECLARE v_START_MDC TIMESTAMP;
	DECLARE v_STOP_MDC  TIMESTAMP;
	DECLARE v_TOTAL_MDC BIGINT;
	DECLARE v_COLOR	 CHAR(10);

	SET v_COLOR = UPPER(i_COLOR);

--	------------------------
--	DELETING FROM CARS_MDC
--	------------------------
	SET v_START_MDC = CURRENT TIMESTAMP;
	DELETE FROM CARS_MDC WHERE COLOR = v_COLOR;
	COMMIT;
	SET v_STOP_MDC  = CURRENT TIMESTAMP;
	SET v_TOTAL_MDC = TIMESTAMPDIFF(1, CHAR(v_STOP_MDC - v_START_MDC));	
	
	INSERT INTO CARS_TIMING_CHECK VALUES ('DELETE','CARS_MDC',v_COLOR,v_START_MDC, v_STOP_MDC, v_TOTAL_MDC);

--	------------------------
--	DELETING FROM CARS
--	------------------------
	SET v_START = CURRENT TIMESTAMP;
	DELETE FROM CARS WHERE COLOR = v_COLOR;
	COMMIT;
	SET v_STOP  = CURRENT TIMESTAMP;
	SET v_TOTAL = TIMESTAMPDIFF(1, CHAR(v_STOP - v_START));	

	INSERT INTO CARS_TIMING_CHECK VALUES ('DELETE','CARS',v_COLOR,v_START, v_STOP, v_TOTAL);

	COMMIT;

END@


-- ------------------------------------------------------------------- 
-- ------------------------------------------------------------------- 
ECHO -@
ECHO -------------------------@
ECHO Creating CARS_UPDATE_CHK Stored procedure..@
ECHO -------------------------@

DROP PROCEDURE CARS_UPDATE_CHK@

CREATE PROCEDURE CARS_UPDATE_CHK (
		     IN i_COLOR CHAR(10) ) 
	
SPECIFIC CARS_UPDATE_CHK
RESULT SETS 0
MODIFIES SQL DATA
LANGUAGE SQL

BEGIN	DECLARE v_START TIMESTAMP;
	DECLARE v_STOP  TIMESTAMP;
	DECLARE v_TOTAL BIGINT;

	DECLARE v_START_MDC TIMESTAMP;
	DECLARE v_STOP_MDC  TIMESTAMP;
	DECLARE v_TOTAL_MDC BIGINT;
	DECLARE v_COLOR	 CHAR(10);

	SET v_COLOR = UPPER(i_COLOR);

--	------------------------
--	UPDATING TO CARS_MDC
--	------------------------
	SET v_START_MDC = CURRENT TIMESTAMP;
	UPDATE CARS_MDC SET COLOR = 'X'||v_COLOR WHERE COLOR = v_COLOR;
	COMMIT;
	SET v_STOP_MDC  = CURRENT TIMESTAMP;
	SET v_TOTAL_MDC = TIMESTAMPDIFF(1, CHAR(v_STOP_MDC - v_START_MDC));	
	
	INSERT INTO CARS_TIMING_CHECK VALUES ('UPDATE','CARS_MDC',v_COLOR,v_START_MDC, v_STOP_MDC, v_TOTAL_MDC);

--	------------------------
--	UPDATING TO CARS
--	------------------------
	SET v_START = CURRENT TIMESTAMP;
	UPDATE CARS SET COLOR = 'X'||v_COLOR WHERE COLOR = v_COLOR;
	COMMIT;
	SET v_STOP  = CURRENT TIMESTAMP;
	SET v_TOTAL = TIMESTAMPDIFF(1, CHAR(v_STOP - v_START));	

	INSERT INTO CARS_TIMING_CHECK VALUES ('UPDATE','CARS',v_COLOR,v_START, v_STOP, v_TOTAL);

	COMMIT;

END@


-- ------------------------------------------------------------------- 
-- ------------------------------------------------------------------- 
ECHO -@
ECHO -------------------------@
ECHO Creating CARS_INSERT_CHK Stored procedure..@
ECHO -------------------------@

DROP PROCEDURE CARS_INSERT_CHK@

CREATE PROCEDURE CARS_INSERT_CHK (
		 IN i_COLOR CHAR(10) ) 
	
SPECIFIC CARS_INSERT_CHK
RESULT SETS 0
MODIFIES SQL DATA
LANGUAGE SQL

BEGIN	DECLARE v_START TIMESTAMP;
	DECLARE v_STOP  TIMESTAMP;
	DECLARE v_TOTAL BIGINT;

	DECLARE v_START_MDC TIMESTAMP;
	DECLARE v_STOP_MDC  TIMESTAMP;
	DECLARE v_TOTAL_MDC BIGINT;
	DECLARE v_COLOR	 CHAR(10);

	SET v_COLOR = UPPER(i_COLOR);

--	------------------------
--	INSERTING TO CARS_MDC
--	------------------------
	SET v_START_MDC = CURRENT TIMESTAMP;
	INSERT INTO CARS_MDC VALUES ('VW BUG',v_COLOR,'1999',99);
	COMMIT;
	SET v_STOP_MDC  = CURRENT TIMESTAMP;
	SET v_TOTAL_MDC = TIMESTAMPDIFF(1, CHAR(v_STOP_MDC - v_START_MDC));	
	
	INSERT INTO CARS_TIMING_CHECK VALUES ('INSERT','CARS_MDC',v_COLOR,v_START_MDC, v_STOP_MDC, v_TOTAL_MDC);

--	------------------------
--	INSERTING TO CARS
--	------------------------
	SET v_START = CURRENT TIMESTAMP;
	INSERT INTO CARS VALUES ('VW BUG',v_COLOR,'1999',99);
	COMMIT;
	SET v_STOP  = CURRENT TIMESTAMP;
	SET v_TOTAL = TIMESTAMPDIFF(1, CHAR(v_STOP - v_START));	

	INSERT INTO CARS_TIMING_CHECK VALUES ('INSERT','CARS',v_COLOR,v_START, v_STOP, v_TOTAL);
	COMMIT;
END@