::  Copyright(r) IBM Corporation
::
::  Report bugs to : Vikram Khatri (vkhatri@us.ibm.com)
::

REM ------------------------------------------------------------------- 
REM DEMONSTRATE RECOVER A DROPPED TABLE                                                
REM ------------------------------------------------------------------- 

SET OUTFILE=%~n0_OUTPUT.TXT

@echo off
cls

ECHO Executed by: %USERNAME% Machine: %COMPUTERNAME% On %OS% %DATE% %TIME% 
ECHO Executed by: %USERNAME% Machine: %COMPUTERNAME% On %OS% %DATE% %TIME% > %OUTFILE%
ECHO DEMONSTRATE RECOVER A DROPPED TABLE
ECHO.

ECHO.
ECHO  Step - 1: Take offline backup of the database
ECHO.

ECHO.
ECHO QUIESCING TEST DATABASE
ECHO.

db2 CONNECT TO TEST  >> %OUTFILE%
db2 QUIESCE DATABASE IMMEDIATE FORCE CONNECTIONS  >> %OUTFILE%
db2 CONNECT RESET  >> %OUTFILE%

ECHO.
ECHO STARTING OFFLINE BACKUP OF TEST DATABASE
ECHO.

db2 BACKUP DATABASE TEST TO "C:\DB2Backup" WITHOUT PROMPTING  >> %OUTFILE%

db2 CONNECT TO TEST  >> %OUTFILE%

ECHO.
ECHO UNQUIESCING TEST DATABASE
ECHO.

db2 UNQUIESCE DATABASE  >> %OUTFILE%
db2 CONNECT RESET  >> %OUTFILE%

ECHO.
ECHO  Step - 2: CREATE A TABLE, INSERT THE DATA AND DROP THE TABLE
ECHO.

db2 connect to test  >> %OUTFILE%
db2 create table recoverme (c1 int not null) >> %OUTFILE%
db2 insert into recoverme values (1),(2),(3),(4),(5),(6),(7) >> %OUTFILE%
db2 drop table recoverme >> %OUTFILE%
db2 connect reset  >> %OUTFILE%

ECHO.
ECHO  Step - 3: See history of dropped table
ECHO.

ECHO HISTRY OF DROPPED TABLE BEGINS HERE >>  %OUTFILE%
db2 list history dropped table all for test >>  %OUTFILE%
ECHO HISTRY OF DROPPED TABLE ENDS HERE >>  %OUTFILE%

ECHO.
ECHO  Step - 4: Restore tablespace from last full backup
ECHO.

db2 CONNECT TO TEST >> %OUTFILE%

ECHO QUIESCING TEST DATABASE
ECHO.

db2 QUIESCE DATABASE IMMEDIATE FORCE CONNECTIONS >> %OUTFILE%
db2 CONNECT RESET >> %OUTFILE%

setlocal
goto :start

:printline
set timestamp=%1                         In God we trust
set timestamp=%timestamp:~0,14%

goto :EOF

:start
FOR /F "tokens=3" %%K in ('db2 list history backup all for test ^| FindStr /C:" B  D " ^| FindStr /C:" F    D "') do call :printline %%K

ECHO STARTING RESTORE OF TABLESPACE(USERSPACE1) IN TEST DATABASE FOR TIMESTAMP %timestamp% >> %OUTFILE%
db2 RESTORE DATABASE TEST TABLESPACE(USERSPACE1) FROM "c:\db2backup" TAKEN AT %timestamp% WITHOUT ROLLING FORWARD WITHOUT PROMPTING >> %OUTFILE%

endlocal

db2 CONNECT TO TEST  >> %OUTFILE%

ECHO.
ECHO UNQUIESCING TEST DATABASE
ECHO.

db2 UNQUIESCE DATABASE  >> %OUTFILE%
db2 CONNECT RESET  >> %OUTFILE%

ECHO.
ECHO  Step - 5: Unload dropped table data using TABLEID from dropped table history
ECHO.

setlocal
goto :start2

:printline2
set tableid=%1

goto :EOF

:start2
FOR /F "tokens=4" %%K in ('db2 list history dropped table all for test ^| FindStr /C:" D  T "') do call :printline2 %%K


ECHO ECHO RECOVERING DROPPED TABLE ID %tableid% DATA TO c:\db2backup >> %OUTFILE%
db2 rollforward database TEST to end of logs and complete recover dropped table %tableid% to "c:\db2backup" >> %OUTFILE%

endlocal

ECHO.
ECHO  Step - 6: RE-CREATE TABLE USING DDL.
ECHO.

db2 connect to test  >> %OUTFILE%
db2 create table recoverme (c1 int not null) >> %OUTFILE%
db2 connect reset  >> %OUTFILE%

ECHO.
ECHO  Step - 7: LOAD DATA IN TABLE
ECHO.

db2 connect to test  >> %OUTFILE%
db2 load from "c:\db2backup\node0000\data" OF DEL METHOD p(1) insert into recoverme  >> %OUTFILE%
db2 connect reset  >> %OUTFILE%

ECHO Note: Restoring dropped table involves 7 different steps.
ECHO Please review each step carefully.
ECHO Check the OUTPUT FILE '%OUTFILE%'
ECHO.
