::  Copyright(r) IBM Corporation
::
::  Report bugs to : Vikram Khatri (vkhatri@us.ibm.com)
::

REM ------------------------------------------------------------------- 
REM DELTA BACKUP / RESTORE / RECOVERY OF TABLESPACES                                               
REM ------------------------------------------------------------------- 

SET OUTFILE=%~n0_OUTPUT.TXT

@echo off
cls


ECHO Executed by: %USERNAME% Machine: %COMPUTERNAME% On %OS% %DATE% %TIME% 
ECHO Executed by: %USERNAME% Machine: %COMPUTERNAME% On %OS% %DATE% %TIME% > %OUTFILE%
ECHO DELTA BACKUP / RESTORE / RECOVERY OF TABLESPACES  
ECHO.

ECHO.
ECHO Step 1: CHECKING TRACKMOD PARAMETER
ECHO.

REM
REM CHECK FOR TRACKMOD FOR TEST DATABASE
REM IF NOT SET, SET THIS PARAMETER 
FOR /F "tokens=6" %%K in ('db2 get db cfg for test ^| findstr /I /C:"trackmod"') do SET TRACKMOD=%%K >> %OUTFILE%
IF "%TRACKMOD%" NEQ "ON " (
   ECHO TRACKMOD IS NOT SET FOR TEST DATABASE. SETTING IT UP NOW.
   db2 update db cfg for test using trackmod on >> %OUTFILE%
   db2 terminate >> %OUTFILE%
)


ECHO.
ECHO Step 2: Create DATA16 and IDX16 TABLESPACES at C:\DB2
ECHO         Create STRAWMAN TABLE
ECHO.


db2 -tf Backup07310.DDL >> %OUTFILE%

ECHO.
ECHO Step 3: Create 1000 rows in STRAWMAN TABLE
ECHO.


db2 -tf Backup07312.DDL >> %OUTFILE%

ECHO.
ECHO Step 4: TAKE OFFLINE BACKUP OF TEST DATABASE
ECHO.

REM
REM Check if C:\db2backup directory exists or not. If not create a new one.
REM

IF NOT EXIST C:\db2backup\nul (
  ECHO.
  ECHO CREATING C:\DB2BACKUP directory
  ECHO.
  mkdir c:\DB2Backup
)

db2 CONNECT TO TEST  >> %OUTFILE%

ECHO.
ECHO QUIESCING TEST DATABASE
ECHO.

db2 QUIESCE DATABASE IMMEDIATE FORCE CONNECTIONS  >> %OUTFILE%
db2 CONNECT RESET  >> %OUTFILE%

ECHO.
ECHO STARTING OFFLINE BACKUP OF TEST DATABASE
ECHO.

db2 BACKUP DATABASE TEST TO "C:\DB2Backup" WITHOUT PROMPTING  >> %OUTFILE%

db2 CONNECT TO TEST  >> %OUTFILE%

ECHO.
ECHO UNQUIESCING TEST DATABASE
ECHO.

db2 UNQUIESCE DATABASE  >> %OUTFILE%
db2 CONNECT RESET  >> %OUTFILE%

ECHO.
ECHO Step 5: Create another 1000 rows in STRAWMAN TABLE
ECHO.

db2 -tf Backup07312.DDL >> %OUTFILE%

ECHO.
ECHO Step 6: TAKE 1st DELTA BACKUP OF DATA16 and IDX16 TABLESPACES
ECHO.

db2 backup database test online incremental delta to c:\db2backup >> %OUTFILE%

ECHO.
ECHO Step 7: Create another 1000 rows in STRAWMAN TABLE
ECHO.

db2 -tf Backup07312.DDL >> %OUTFILE%

ECHO.
ECHO Step 8: TAKE 2nd DELTA BACKUP OF DATA16 and IDX16 TABLESPACES
ECHO.

db2 backup database test online incremental delta to c:\db2backup >> %OUTFILE%

ECHO.
ECHO Step 9: Create another 1000 rows in STRAWMAN TABLE
ECHO.

db2 -tf Backup07312.DDL >> %OUTFILE%

ECHO.
ECHO Step 10: RESTORE TEST DATABASE OFFLINE
ECHO.

db2 CONNECT TO TEST >> %OUTFILE%

ECHO QUIESCING TEST DATABASE
ECHO.

db2 QUIESCE DATABASE IMMEDIATE FORCE CONNECTIONS >> %OUTFILE%
db2 CONNECT RESET >> %OUTFILE%

setlocal
goto :start

:printline
set timestamp=%1                         In God we trust
set timestamp=%timestamp:~0,14%

goto :EOF

:start
FOR /F "tokens=3" %%K in ('db2 list history backup all for test ^| FindStr /C:" B  D " ^| FindStr /C:" F    D "') do call :printline %%K

ECHO STARTING RESTORE OF TEST DATABASE FOR TIMESTAMP %timestamp% >> %OUTFILE%
db2 RESTORE DATABASE TEST FROM "c:\db2backup" TAKEN AT %timestamp% WITHOUT PROMPTING >> %OUTFILE%

endlocal

ECHO.
ECHO Step 11: APPLY DELTA BACKUP (AUTOMATIC) TO TEST DATABASE
ECHO.

setlocal
goto :start2

:printline2
set timestamp=%1                         In God we trust
set timestamp=%timestamp:~0,14%

goto :EOF

:start2
FOR /F "tokens=3" %%K in ('db2 list history backup all for test ^| FindStr /C:" B  D " ^| FindStr /C:" F    D "') do call :printline2 %%K

ECHO STARTING INCREMENTAL RESTORE OF TEST DATABASE FOR TIMESTAMP %timestamp% >> %OUTFILE%
db2 restore database test incremental automatic from c:\db2backup taken at %timestamp% without prompting >> %OUTFILE%

endlocal

ECHO.
ECHO Step 12: Roll forward Transactions
ECHO.

db2 rollforward database test to end of logs and complete >> %OUTFILE%

db2 CONNECT TO TEST  >> %OUTFILE%

ECHO.
ECHO UNQUIESCING TEST DATABASE
ECHO.

db2 UNQUIESCE DATABASE  >> %OUTFILE%
db2 CONNECT RESET  >> %OUTFILE%


ECHO.
ECHO Step 10: CHECK ROWS IN STRAWMAN TABLE
ECHO.

db2 Connect to test >> %OUTFILE%
db2 "select count(*) from STRAWMAN"
db2 connect reset >> %OUTFILE%

ECHO Note: The heart of this script is "backup database test incremental delta"
ECHO "restore database incremental automatic" and "Rollforward"
ECHO Please review these three commands carefully.
ECHO Check the OUTPUT FILE '%OUTFILE%'
ECHO.
