::  Copyright(r) IBM Corporation
::
::  Vikram Khatri (vkhatri@us.ibm.com)
::

REM ------------------------------------------------------------------- 
REM Configure HADR between DB2_P and DB2_S Instances for RUGBY database
REM ------------------------------------------------------------------- 

SET OUTFILE=%~n0_OUTPUT.TXT

@echo off
cls


REM
REM SET DBAPOT user password to DBAPOT. Lab assumes DBAPOT password as DBAPOT.
SET USERPWD=
IF /I "%USERNAME%" EQU "DBAPOT" (
  ECHO Setting password for %USERNAME% 
  SET USERPWD=dbapot
)

ECHO Executed by: %USERNAME% Machine: %COMPUTERNAME% On %OS% %DATE% %TIME% 
ECHO Executed by: %USERNAME% Machine: %COMPUTERNAME% On %OS% %DATE% %TIME% > %OUTFILE%
ECHO Configure HADR between DB2_P and DB2_S Instances for RUGBY database
ECHO.


REM
REM Remove directories
REM

IF EXIST C:\DB2Backup\nul (
   rmdir /s/q C:\DB2Backup >> %OUTFILE%
)
IF EXIST C:\DB2HADRSharedLogArch\nul (
   rmdir /s/q C:\DB2HADRSharedLogArch >> %OUTFILE%
)

ECHO.
ECHO Step 1: Create DB2_P instance. (Drop the instance if it exists)
ECHO.

SET INSTANCEFOUND=false
FOR /F "tokens=1" %%K in ('db2ilist') do (
   IF "%%K" EQU "DB2_P" (
      SET INSTANCEFOUND=true
      break
   )
)

IF "%INSTANCEFOUND%" EQU "true" (
   ECHO Dropping DB2_P instance
   set db2instance=DB2_P
   db2 terminate >> %OUTFILE%
   db2stop FORCE  >> %OUTFILE%
   db2idrop DB2_P >>  %OUTFILE%

   IF EXIST C:\DB2_P\nul (
     rmdir /s/q C:\DB2_P >> %OUTFILE%
   )

   IF EXIST "%ProgramFiles%\IBM\SQLLIB\DB2_P\nul" (
     rmdir /s/q "%ProgramFiles%\IBM\SQLLIB\DB2_P" >> %OUTFILE%
   )
)

ECHO Creating DB2_P instance

IF "%USERPWD%" EQU "" (
  db2icrt -s ESE -u %USERNAME% -r 51600,51600 DB2_P
) else (
  db2icrt -s ESE -u %USERNAME%,%USERPWD% -r 51600,51600 DB2_P
)

IF NOT EXIST C:\DB2_P\nul (
  ECHO.
  ECHO CREATING C:\DB2_P directory
  ECHO.
  mkdir c:\DB2_P >> %OUTFILE%
)
set db2instance=DB2_P
db2 UPDATE DBM CFG USING SVCENAME DB2_DB2_P >> %OUTFILE%
db2set DB2COMM=TCPIP 
findstr /C:"DB2_HADR_1" "%WINDIR%\system32\drivers\etc\services"  >> %OUTFILE%
IF ERRORLEVEL 1 (
  ECHO DB2_HADR_1 not found in services file >> %OUTFILE%
  ECHO Creating DB2_HADR_1 entry in %WINDIR%\system32\drivers\etc\services >> %OUTFILE%
  ECHO DB2_HADR_1      55001/tcp >> "%WINDIR%\system32\drivers\etc\services"
) else (
  ECHO %WINDIR%\system32\drivers\etc\services already contains DB2_HADR_1 entry >> %OUTFILE%
)
ECHO Starting DB2_P instance
db2start >> %OUTFILE%
db2 get instance >> %OUTFILE%

ECHO.
ECHO Step 2: Create RUGBY Database in DB2_P instance.
ECHO.

db2 CREATE DATABASE RUGBY >> %OUTFILE%

ECHO.
ECHO Step 3: Turn on Archival Logging for RUGBY database in DB2_P
ECHO.

IF NOT EXIST C:\DB2HADRSharedLogArch\nul (
  ECHO.
  ECHO CREATING C:\DB2HADRSharedLogArch directory
  ECHO.
  mkdir C:\DB2HADRSharedLogArch >> %OUTFILE%
)

ECHO Update LOGINDEXBUILD and INDEXREC parameters for RUGBY database in DB2_P >> %OUTFILE%
db2 UPDATE DB CFG FOR RUGBY USING LOGINDEXBUILD ON >> %OUTFILE%
db2 UPDATE DB CFG FOR RUGBY USING INDEXREC RESTART >> %OUTFILE%

ECHO Turn on Archival Logging for RUGBY database in DB2_P >> %OUTFILE%
db2 UPDATE DB CFG FOR RUGBY USING logarchmeth1 "DISK:C:\DB2HADRSharedLogArch" >> %OUTFILE%

IF NOT EXIST C:\DB2BACKUP\nul (
  ECHO.
  ECHO CREATING C:\DB2BACKUP directory
  ECHO.
  mkdir C:\DB2BACKUP >> %OUTFILE%
)

ECHO Backup Database RUGBY to "C:\DB2Backup"
ECHO Backup Database RUGBY to "C:\DB2Backup" >> %OUTFILE%
db2 BACKUP DATABASE RUGBY TO "C:\DB2Backup" WITHOUT PROMPTING >> %OUTFILE%

ECHO.
ECHO Step 4: Create DB2_S instance. (Drop the instance if it exists)
ECHO.

SET INSTANCEFOUND=false
FOR /F "tokens=1" %%K in ('db2ilist') do (
   IF "%%K" EQU "DB2_S" (
      SET INSTANCEFOUND=true
      break
   )
)

IF "%INSTANCEFOUND%" EQU "true" (
   ECHO Dropping DB2_S instance
   set db2instance=DB2_S
   db2 terminate >> %OUTFILE%
   db2stop FORCE  >> %OUTFILE%
   db2idrop DB2_S >>  %OUTFILE%

   IF EXIST C:\DB2_S\nul (
     rmdir /s/q C:\DB2_S >> %OUTFILE%
   )

   IF EXIST "%ProgramFiles%\IBM\SQLLIB\DB2_S\nul" (
     rmdir /s/q "%ProgramFiles%\IBM\SQLLIB\DB2_S" >> %OUTFILE%
   )
)

ECHO Creating DB2_S instance

IF "%USERPWD%" EQU "" (
  db2icrt -s ESE -u %USERNAME% -r 51700,51700 DB2_S
) else (
  db2icrt -s ESE -u %USERNAME%,%USERPWD% -r 51700,51700 DB2_S
)

IF NOT EXIST C:\DB2_S\nul (
  ECHO.
  ECHO CREATING C:\DB2_S directory
  ECHO.
  mkdir c:\DB2_S >> %OUTFILE%
)
set db2instance=DB2_S
db2 UPDATE DBM CFG USING SVCENAME DB2_DB2_S >> %OUTFILE%
db2set DB2COMM=TCPIP 
findstr /C:"DB2_HADR_2" "%WINDIR%\system32\drivers\etc\services"  >> %OUTFILE%
IF ERRORLEVEL 1 (
  ECHO DB2_HADR_2 not found in services file >> %OUTFILE%
  ECHO Creating DB2_HADR_2 entry in %WINDIR%\system32\drivers\etc\services >> %OUTFILE%
  ECHO DB2_HADR_2      55002/tcp >> "%WINDIR%\system32\drivers\etc\services"
) else (
  ECHO %WINDIR%\system32\drivers\etc\services already contains DB2_HADR_2 entry >> %OUTFILE%
)
ECHO Starting DB2_S instance
db2start >> %OUTFILE%
db2 get instance >> %OUTFILE%

ECHO.
ECHO Step 5: Restore RUGBY Database in DB2_S instance.
ECHO.

ECHO Restoring RUGBY database from backup in DB2_S instance
db2 RESTORE DB RUGBY FROM C:\DB2BACKUP REPLACE HISTORY FILE WITHOUT PROMPTING >> %OUTFILE%

ECHO.
ECHO Step 6: Catalog Node and Databases in DB2_P and DB2_S instances
ECHO.

set db2instance=DB2_P
db2 CATALOG LOCAL NODE DB2_S INSTANCE DB2_S >> %OUTFILE%
db2 CATALOG DB RUGBY AS RUGBYP >> %OUTFILE%
db2 CATALOG DB RUGBY AS RUGBYS AT NODE DB2_S >> %OUTFILE%

set db2instance=DB2_S
db2 CATALOG LOCAL NODE DB2_P INSTANCE DB2_P >> %OUTFILE%
db2 CATALOG DB RUGBY AS RUGBYS >> %OUTFILE%
db2 CATALOG DB RUGBY AS RUGBYP AT NODE DB2_P >> %OUTFILE%

ECHO.
ECHO Step 7: Configure Client Re-route in DB2_P/DB2_S instances for RUGBY database
ECHO.

set db2instance=DB2_P
db2 UPDATE ALTERNATE SERVER FOR DATABASE RUGBYS USING HOSTNAME %COMPUTERNAME% PORT 51700 >> %OUTFILE%

set db2instance=DB2_S
db2 UPDATE ALTERNATE SERVER FOR DATABASE RUGBYP USING HOSTNAME %COMPUTERNAME% PORT 51600 >> %OUTFILE%

ECHO.
ECHO Step 8: Configure HADR in DB2_P instance for database RUGBY
ECHO.

set db2instance=DB2_P
db2 UPDATE DB CFG FOR RUGBY USING HADR_LOCAL_HOST %COMPUTERNAME% HADR_LOCAL_SVC DB2_HADR_1 HADR_REMOTE_HOST %COMPUTERNAME% HADR_REMOTE_SVC DB2_HADR_2 HADR_REMOTE_INST DB2_S HADR_SYNCMODE SYNC HADR_TIMEOUT 120 >> %OUTFILE%

ECHO.
ECHO Step 9: Configure HADR in DB2_S instance for database RUGBY
ECHO.

set db2instance=DB2_S
db2 UPDATE DB CFG FOR RUGBY USING HADR_LOCAL_HOST %COMPUTERNAME% HADR_LOCAL_SVC DB2_HADR_2 HADR_REMOTE_HOST %COMPUTERNAME% HADR_REMOTE_SVC DB2_HADR_1 HADR_REMOTE_INST DB2_P HADR_SYNCMODE SYNC HADR_TIMEOUT 120 >> %OUTFILE%

ECHO.
ECHO Step 10: Start HADR on DB2_S in Standby mode
ECHO.

set db2instance=DB2_S
db2 START HADR ON DATABASE RUGBY AS STANDBY >> %OUTFILE%

ECHO.
ECHO Step 11: Start HADR on DB2_P in Primary mode
ECHO.

set db2instance=DB2_P
db2 START HADR ON DATABASE RUGBY AS PRIMARY >> %OUTFILE%

ECHO.
ECHO Step 12: Catalog node and database in DB2 Instance
ECHO.

set DB2INSTANCE=DB2
db2 CATALOG LOCAL NODE DB2_P INSTANCE DB2_P >> %OUTFILE%
db2 CATALOG DB RUGBY AS RUGBYP AT NODE DB2_P >> %OUTFILE%
db2 CATALOG LOCAL NODE DB2_S INSTANCE DB2_S >> %OUTFILE%
db2 CATALOG DB RUGBY AS RUGBYS AT NODE DB2_S >> %OUTFILE%



